@@ -3,7 +3,7 @@ package Meow;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 require XSLoader;
 XSLoader::load('Meow', $VERSION);
@@ -20,7 +20,7 @@ Meow - Object ฅ^•ﻌ•^ฅ Orientation
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
@@ -33,9 +33,9 @@ This module is experimental. Many basic features do not yet exist.
 	use Meow;
 	use Basic::Types::XS qw/Str Num/;
 
-	rw name => Str;
+	ro name => Str;
 
-	rw age => Num;
+	rw age => Default(Num, 0);
 
 	1;
 
